Expr

Enum Expr 

pub enum Expr<A: AstTypes = DefaultTypes> {
    Omitted,
    Id(A::Path),
    MetId(A::MacroId),
    Lit(A::Literal),
    Use(Use<A>),
    Bind(Box<Bind<A>>),
    Make(Box<Make<A>>),
    Match(Box<Match<A>>),
    Op(Op, Vec<At<Self, A>>),
}
Expressions: The beating heart of Conlang.

A program in Conlang is a single expression which, at compile time, sets up the state in which a program will run. This expression binds types, functions, and values to names which are exposed at runtime.

Whereas in the body of a function, do sequences are ordered, in the global scope (or subsequent module scopes, which are children of the global module,) do sequences are considered unordered, and subexpressions may be reordered in whichever way the compiler sees fit. This is especially important when performing import resolution, as imports typically depend on the order in which names are bound.

Variants



Omitted

Omitted by semicolon insertion-elision rules



Id(A::Path)

An identifier



MetId(A::MacroId)

An escaped token for macro binding



Lit(A::Literal)

A literal bool, string, char, or int



Use(Use<A>)

use Use



Bind(Box<Bind<A>>)

let Pat::NoTopAlt (= expr (else expr)?)? | (fn | mod | impl) Pat::Fn Expr



Make(Box<Make<A>>)

Expr { (Ident (: Expr)?),* }



Match(Box<Match<A>>)

match Expr { (Pat => Expr),* }



Op(Op, Vec<At<Self, A>>)

Op Expr | Expr Op | Expr (Op Expr)+ | Op Expr Expr else Expr

Implementations

Source

impl<A: AstTypes> Expr<A>

pub const fn at(self, annotation: A::Annotation) -> At<Expr<A>, A>

Attaches this Expr to an At node with the provided Annotation.

pub fn and_do(self, annotation: A::Annotation, other: At<Expr<A>, A>) -> Self

Attaches another expression to this one, continuing a do chain if possible.

pub fn to_tuple(self, annotation: A::Annotation) -> Self

Turns this expression into a tuple if it isn’t already one.

pub const fn is_place(&self) -> bool

Returns whether self is a “place projection” expression (identifier, index, dot, or deref)

pub const fn is_value(&self) -> bool

Returns whether self is NOT a “place projection” expression

pub const fn as_slice(&self) -> Option<(Op, &[At<Expr<A>, A>])>

If self is an Expr::Op, returns the Op and a slice of its arguments.