PatOp

Enum PatOp 

pub enum PatOp {
Show 16 variants Pub, Mut, Ref, Ptr, Rest, RangeEx, RangeIn, Record, Tuple, Slice, ArRep, Typed, TypePrefixed, Generic, Fn, Alt,
}
Operators on lists of patterns

Variants



Pub

Changes the visibility mode to “public”



Mut

Changes the binding mode to “mutable”



Ref

Matches the dereference of a pointer (&pat)



Ptr

Matches the dereference of a raw pointer (*pat)



Rest

Matches a partial decomposition (..rest) or upper-bounded range (..100)



RangeEx

Matches an exclusive bounded range (0..100)



RangeIn

Matches an inclusive bounded range (0..=100)



Record

Matches the elements of a record or struct { a, b, c }



Tuple

Matches the elements of a tuple ( a, b, c )



Slice

Matches the elements of a slice or array [ a, b, c ]



ArRep

Matches a constant-size slice with repeating elements



Typed

Matches a type annotation or struct member



TypePrefixed

Matches a prefix-type-annotated structure



Generic

Matches a generic specialization annotation



Fn

Changes the binding mode to “function-body”



Alt

Matches one of a list of alternatives